- R
Matrix. A correlation matrix of dimensions p by p.
- n
Numeric. The sample size used to compute the information criterion.
- penalty
Character string. Which penalty should be used (defaults to "atan")?
- ic
Character string. Which information criterion should be used (defaults to "bic")?
The options include aic, ebic (ebic_gamma defaults to 0.5),
ric, or any of the generalized information criteria provided in section 5 of
kim2012consistent;textualGGMncv. The options are gic_1
(i.e., bic) to gic_6 (see 'Details').
- select
Character string. Which tuning parameter should be selected
(defaults to "lambda")? The options include "lambda"
(the regularization parameter), "gamma" (governs the 'shape'),
and "both".
- gamma
Numeric. Hyperparameter for the penalty function.
Defaults to 3.7 (scad), 2 (mcp), 0.5 (adapt),
and 0.01 with all other penalties. Note care must be taken when
departing from the default values
(see the references in 'note')
- lambda
Numeric vector. Regularization (or tuning) parameters.
The defaults is NULL that provides default
values with select = "lambda" and sqrt(log(p)/n) with
select = "gamma".
- n_lambda
Numeric. The number of 's to be evaluated. Defaults to 50.
This is disregarded if custom values are provided for lambda.
- lambda_min_ratio
Numeric. The smallest value for lambda, as a
fraction of the upperbound of the
regularization/tuning parameter. The default is
0.01, which mimics the R package
qgraph. To mimic the R package
huge, set lambda_min_ratio = 0.1
and n_lambda = 10.
- n_gamma
Numeric. The number of 's to be evaluated. Defaults to 50.
This is disregarded if custom values are provided in lambda.
- initial
A matrix (p by p) or custom function that returns
the inverse of the covariance matrix . This is used to compute
the penalty derivative. The default is NULL, which results
in using the inverse of R (see 'Note').
- LLA
Logical. Should the local linear approximation be used (default to FALSE)?
- unreg
Logical. Should the models be refitted (or unregularized) with maximum likelihood
(defaults to FALSE)? Setting to TRUE results in the approach of
Foygel2010;textualGGMncv, but with the regularization path obtained from
nonconvex regularization, as opposed to the _1-penalty.
- maxit
Numeric. The maximum number of iterations for determining convergence of the LLA
algorithm (defaults to 1e4). Note this can be changed to, say,
2 or 3, which will provide two and three-step estimators
without convergence check.
- thr
Numeric. Threshold for determining convergence of the LLA algorithm
(defaults to 1.0e-4).
- store
Logical. Should all of the fitted models be saved (defaults to TRUE)?
- progress
Logical. Should a progress bar be included (defaults to TRUE)?
- ebic_gamma
Numeric. Value for the additional hyper-parameter for the
extended Bayesian information criterion (defaults to 0.5,
must be between 0 and 1). Setting ebic_gamma = 0 results
in BIC.
- penalize_diagonal
Logical. Should the diagonal of the inverse covariance
matrix be penalized (defaults to TRUE).
- ...
Additional arguments passed to initial when a
function is provided and ignored otherwise.