Learn R Programming

GGMncv (version 2.1.2)

plot.graph: Network Plot for select Objects

Description

Visualize the conditional dependence structure.

Usage

# S3 method for graph
plot(
  x,
  layout = "circle",
  neg_col = "#D55E00",
  pos_col = "#009E73",
  edge_magnify = 1,
  node_size = 10,
  palette = 2,
  node_names = NULL,
  node_groups = NULL,
  ...
)

Value

An object of class ggplot

Arguments

x

An object of class graph obtained from get_graph.

layout

Character string. Which graph layout (defaults is circle) ? See gplot.layout.

neg_col

Character string. Color for the positive edges (defaults to a colorblind friendly red).

pos_col

Character string. Color for the negative edges (defaults to a colorblind friendly green).

edge_magnify

Numeric. A value that is multiplied by the edge weights. This increases (> 1) or decreases (< 1) the line widths (defaults to 1).

node_size

Numeric. The size of the nodes (defaults to 10).

palette

A character string sepcifying the palette for the groups. (default is Set3). See palette options here.

node_names

Character string. Names for nodes of length p.

node_groups

A character string of length p (the number of nodes in the model). This indicates groups of nodes that should be the same color (e.g., "clusters" or "communities").

...

Currently ignored.

Examples

Run this code
# \donttest{

Y <- na.omit(bfi[,1:25])

fit <- ggmncv(cor(Y), n = nrow(Y),
              progress = FALSE)

plot(get_graph(fit))

# }

Run the code above in your browser using DataLab