print.eip: Print eip Objects
Description
Print eip Objects
Usage
# S3 method for eip
print(x, ...)
Value
Invisibly returns x, the input object of class eip.
The method is called for its side effect of printing a data frame with
the edge relations and their edge inclusion probabilities.
Arguments
- x
An object of class eip
- ...
Currently ignored.