Learn R Programming

GGMncv (version 2.1.2)

print.ggmncv: Print ggmncv Objects

Description

Print ggmncv Objects

Usage

# S3 method for ggmncv
print(x, ...)

Value

Invisibly returns x, the input object of class ggmncv. The method is called primarily for its side effect of printing a summary of the fitted model object. The printed output depends on the additional class of x; it may summarize the default fitted model, coefficient output, inference results, or model-comparison results.

Arguments

x

An object of class ggmncv.

...

Currently ignored.