Learn R Programming

GGMncv (version 2.1.2)

print.nct: Print nct Objects

Description

Print nct Objects

Usage

# S3 method for nct
print(x, ...)

Value

Invisibly returns x, the input object of class nct. The method is called primarily for its side effect of printing the results of the network comparison test, including p-values for the maximum difference, global strength, sum of squared error, and Jensen-Shannon divergence statistics stored in the object.

Arguments

x

An object of class nct.

...

Currently ignored.