Learn R Programming

GGMncv (version 2.1.2)

boot_eip: Bootstrapped Edge Inclusion 'Probabilities'

Description

Compute the number of times each edge was selected when performing a non-parametric bootstrap @see Figure 6.7, @hastie2009elementsGGMncv.

Usage

boot_eip(Y, method = "pearson", samples = 500, progress = TRUE, ...)

Value

An object of class eip that includes the "probabilities" in a data frame.

Arguments

Y

A matrix of dimensions n by p.

method

Character string. Which correlation coefficient (or covariance) is to be computed. One of "pearson" (default), "kendall", or "spearman".

samples

Numeric. How many bootstrap samples (defaults to 500)?

progress

Logical. Should a progress bar be included (defaults to TRUE)?

...

Additional arguments passed to ggmncv.

References

Examples

Run this code

# \donttest{
# data (ptsd symptoms)
Y <- GGMncv::ptsd[,1:10]

# compute eip's
boot_samps <- boot_eip(Y, samples  = 100, progress = FALSE)

boot_samps
# }

Run the code above in your browser using DataLab