head.eip: Print the Head of eip Objects
Description
Print the Head of eip Objects
Usage
# S3 method for eip
head(x, n = 5, ...)
Value
Invisibly returns a data frame containing the first n rows of
x$eip_results. The returned data frame contains the leading edge
relations and their edge inclusion probabilities, and is printed as a side
effect.
Arguments
- x
An object of class eip
- n
Numeric. Number of rows to print.
- ...
Currently ignored.