ggmncv ObjectsPrint ggmncv Objects
# S3 method for ggmncv
print(x, ...)Invisibly returns x, the input object of class ggmncv.
The method is called primarily for its side effect of printing a summary
of the fitted model object. The printed output depends on the additional
class of x; it may summarize the default fitted model, coefficient
output, inference results, or model-comparison results.
An object of class ggmncv.
Currently ignored.