nct ObjectsPrint nct Objects
# S3 method for nct
print(x, ...)Invisibly returns x, the input object of class nct.
The method is called primarily for its side effect of printing the results
of the network comparison test, including p-values for the maximum
difference, global strength, sum of squared error, and Jensen-Shannon
divergence statistics stored in the object.
An object of class nct.
Currently ignored.